<template>
  <!-- <div> -->
  <!-- <div>1111111111111111111111111111111111111111</div> -->
  <div :class="className" :style="{height:height,width:width}" />
  <!-- </div> -->
</template>

<script>
import echarts from 'echarts'
require('echarts/theme/macarons') // echarts theme
import resize from './mixins/resize'

export default {
  mixins: [resize],
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '350px'
    },
    autoResize: {
      type: Boolean,
      default: true
    },
    chartData: {
      type: Object,
      required: true
    }
    // xdata: {
    //   type: Array,
    //   required: true
    // }
  },
  data() {
    return {
      chart: null
    }
  },
  watch: {
    chartData: {
      deep: true,
      handler(val) {
        this.setOptions(val)
      }
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart()
    })
  },
  beforeDestroy() {
    if (!this.chart) {
      return
    }
    this.chart.dispose()
    this.chart = null
  },
  methods: {
    initChart() {
      this.chart = echarts.init(this.$el, 'macarons')
      this.setOptions(this.chartData)
    },
    setOptions(val) {
      this.chart.setOption({
        xAxis: {
          data: val.xAxis,
          boundaryGap: false,
          axisTick: {
            show: false
          }
        },
        grid: {
          left: 10,
          right: 10,
          bottom: 20,
          top: 30,
          containLabel: true
        },
        toolbox: {
          feature: {
            dataZoom: {
              yAxisIndex: 'none'
            },
            restore: {},
            saveAsImage: {}
          }
        },
        // tooltip: {
        //   trigger: 'axis',
        //   position: function(pt) {
        //     return [pt[0], '10%']
        //   }
        // },
        tooltip: {
          trigger: 'axis',
          position: function(pt) {
            return [pt[0], '10%']
          },
          formatter(params) {
            for (let i = 0; i < params.length; i++) {
              return params[i].seriesName + ':' + '&nbsp;&nbsp;' + params[i].data.data0
            }
          }
        },
        // tooltip: {
        //   trigger: 'axis',
        //   axisPointer: {
        //     type: 'cross'
        //   },
        //   padding: [5, 10]
        // },
        yAxis: {
          axisLabel: {
            show: false
          }
        },
        legend: {
          icon: 'circle',
          itemHeight: 15,
          // textStyle: {
          //   fontSize: 18
          // },
          data: val.title
        },
        dataZoom: [{
          type: 'inside',
          start: 0,
          end: 100
        }, {
          start: 0,
          end: 10
        }],
        series: val.series
        // [{
        //   name: JSON.parse(JSON.stringify(val.title)),
        //   itemStyle: {
        //     normal: {
        //       color: '#7AC5CD',
        //       lineStyle: {
        //         color: '#7AC5CD',
        //         width: 2
        //       }
        //     }
        //   },
        //   smooth: true,
        //   type: 'line',
        //   data: val.series,
        //   animationDuration: 2800,
        //   animationEasing: 'cubicInOut',
        //   areaStyle: {},
        //   label: {
        //     normal: {
        //       show: true,
        //       position: 'top'
        //     }
        //   }
        // }]
      }, true)
    }
  }
}
</script>
